@@ -578,6 +578,10 @@ static void on_url(GtkWidget *widget, const gchar *url, gpointer data)
 	g_return_if_fail(messageview != NULL);
 
 	if (url != NULL) {
+		if (((GtkHtml2Viewer *)viewer)->is_on_url && messageview->statusbar)
+			gtk_statusbar_pop(GTK_STATUSBAR(messageview->statusbar),
+					messageview->statusbar_cid);
+					 	
 		gchar *real_url = make_url(url, ((GtkHtml2Viewer *)data)->base);
 		if (messageview->statusbar)
 			gtk_statusbar_push(GTK_STATUSBAR(messageview->statusbar),
