@@ -98,6 +98,14 @@ typedef struct {
   gint             trayicon_popup_timeout;
 #endif /* HAVE_LIBNOTIFY */
 #endif /* Trayicon */
+#ifdef NOTIFICATION_INDICATOR
+  gboolean indicator_enabled;
+  gboolean indicator_hide_minimized;
+#endif /* NOTIFICATION_INDICATOR */
+#ifdef NOTIFICATION_HOTKEYS
+  gboolean hotkeys_enabled;
+  gchar* hotkeys_toggle_mainwindow;
+#endif /* Hotkeys */
 } NotifyPrefs;
 
 extern NotifyPrefs notify_config;
