@@ -24,6 +24,10 @@
 #  include "config.h"
 #endif
 
+#ifdef G_OS_WIN32
+#  include <w32lib.h>
+#endif
+
 #include <glib.h>
 
 #include <folder.h>
@@ -512,13 +516,14 @@ static gint rssyl_add_msgs(Folder *folder, FolderItem *dest, GSList *file_list,
 		destfile = rssyl_get_new_msg_filename(dest);
 		g_return_val_if_fail(destfile != NULL, -1);
 
-		if( link(fileinfo->file, destfile) < 0 ) {
+#ifdef G_OS_UNIX
+		if( link(fileinfo->file, destfile) < 0 )
+#endif
 			if( copy_file(fileinfo->file, destfile, TRUE) < 0 ) {
 				g_warning("can't copy message %s to %s\n", fileinfo->file, destfile);
 				g_free(destfile);
 				return -1;
 			}
-		}
 
 		if( relation != NULL )
 			g_hash_table_insert(relation, fileinfo,
