@@ -25,6 +25,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
 #include "folderview.h"
 #include "alertpanel.h"
@@ -118,3 +119,36 @@ gboolean rssyl_default_expired_num_toggled_cb(GtkToggleButton *default_ex,
 
 	return FALSE;
 }
+
+gboolean rssyl_fetch_comments_toggled_cb(GtkToggleButton *fetch_comments,
+		gpointer data)
+{
+	gboolean active = gtk_toggle_button_get_active(fetch_comments);
+	GtkWidget *num_comments = (GtkWidget *)data;
+
+	debug_print("fetch comments is %s\n", (active ? "ON" : "OFF") );
+
+	gtk_widget_set_sensitive(num_comments, active);
+
+	return FALSE;
+}
+
+gboolean rssyl_props_key_press_cb(GtkWidget *widget, GdkEventKey *event,
+		gpointer data)
+{
+	if (event) {
+		switch (event->keyval) {
+			case GDK_Escape:
+				rssyl_props_cancel_cb(widget, data);
+				return TRUE;
+			case GDK_Return:
+			case GDK_KP_Enter:
+				rssyl_props_ok_cb(widget, data);
+				return TRUE;
+			default:
+				break;
+		}
+	}
+
+	return FALSE;
+}
