@@ -25,6 +25,9 @@
 #include "gettext.h"
 #include "defs.h"
 
+#ifdef USE_PTHREAD
+#include <pthread.h>
+#endif
 #include <string.h>
 #include <time.h>
 
