@@ -67,7 +67,7 @@ directed to site-policy@w3.org.
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 18 Dec 2002
- * Version: $Id: icaltime_as_local.c,v 1.1.2.4 2008-09-30 15:29:48 colinler Exp $
+ * Version: $Id: icaltime_as_local.c,v 1.1.2.5 2011-03-04 13:38:15 colin Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -75,7 +75,7 @@ directed to site-policy@w3.org.
 #endif
 
 #ifdef USE_PTHREAD
-#include "pthread.h"
+#include <pthread.h>
 #endif
 
 #include "icaltime_as_local.h"
