@@ -24,6 +24,9 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef USE_PTHREAD
+#include <pthread.h>
+#endif
 #include "gettext.h"
 #include <ical.h>
 #include "vcalendar.h"
@@ -44,6 +47,10 @@
 #include "quoted-printable.h"
 #include "utils.h"
 
+#ifdef G_OS_WIN32
+#define getuid() 0
+#endif
+
 Answer *answer_new(const gchar *attendee, 
 			  const gchar *name,
 			  enum icalparameter_partstat ans,
