@@ -24,6 +24,9 @@
 
 #include "defs.h"
 
+#ifdef USE_PTHREAD
+#include <pthread.h>
+#endif
 #include <ical.h>
 #include "gettext.h"
 #include <gtk/gtk.h>
